DataTables example - Add rows

# DataTables example Add rows

New rows can be added to a DataTable very easily using the `row.add()DT` API method. Simply call the API function with the data that is to be used for the new row (be it an array or object). Multiple rows can be added using the `rows.add()DT` method (note the plural).

Note that in order to see the new row in the table you must call the `draw()DT` method, which is easily done through the chaining that the DataTables API makes use of.

This example shows a single row being added each time the button below is clicked upon.

Column 1 | Column 2 | Column 3 | Column 4 | Column 5
--- | --- | --- | --- | ---
Column 1 | Column 2 | Column 3 | Column 4 | Column 5

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { var t = $('#example').DataTable(); var counter = 1; $('#addRow').on( 'click', function () { t.row.add( [ counter +'.1', counter +'.2', counter +'.3', counter +'.4', counter +'.5' ] ).draw(); counter++; } ); // Automatically add a first row of data $('#addRow').click(); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- ../../media/js/jquery.js
- ../../media/js/jquery.dataTables.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

``

The following CSS library files are loaded for use in this example to provide the styling of the table:

- ../../media/css/jquery.dataTables.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.